// AtoD.h: interface for the CAtoD class.
//
//////////////////////////////////////////////////////////////////////

//#if !defined (AFX_ATOD_H__4771592B_B4FA_11D2_A69C_00105AE399E3__INCLUDED_)
#ifndef atod
//#define       AFX_ATOD_H__4771592B_B4FA_11D2_A69C_00105AE399E3__INCLUDED_
#define atod

#if _MSC_VER >= 1000
#pragma once
#endif // _MSC_VER >= 1000

#include "Ibtmexcw.h"

class CAtoD  
{
public:
	//data members--control info for the TMEX session
	short PortType, PortNum;   
    uchar state_buffer[15360];
	long s_handle;
	short ROM[8];
	char driverInfo[500];
	char ROMStr[500];

	//methods
	CAtoD();
	virtual ~CAtoD();
	
	void getChannels(BOOL& A, BOOL& B, BOOL& C, BOOL& D);
	int setChannels(BOOL A, BOOL B, BOOL C, BOOL D);

	float getVoltageReading(uchar forChannel);

    uchar getResolution(uchar forChannel);
	int setResolution(uchar forChannel, uchar newResolution);

	int getOutEnable(uchar forChannel, BOOL& on, BOOL& transistorOff);
	int setOutputEnable(uchar forChannel,BOOL on,BOOL transistorOff);

	BOOL getAlarmH(uchar forChannel);
	int setAlarmH(uchar forChannel,BOOL on);
	BOOL getAlarmHFlag(uchar forChannel);
	int setAlarmHFlag(uchar forChannel,BOOL flag);
	uchar getAlarmHSetting(uchar forChannel);
	int setAlarmHSetting(uchar forChannel, uchar setting);

	BOOL getAlarmL(uchar forChannel);
	int setAlarmL(uchar forChannel,BOOL on);
	BOOL getAlarmLFlag(uchar forChannel);
	int setAlarmLFlag(uchar forChannel,BOOL flag);
	uchar getAlarmLSetting(uchar forChannel);
	int setAlarmLSetting(uchar forChannel, uchar setting);

	

	BOOL getVoltageRange(uchar forChannel);
	int setVoltageRange(uchar forChannel, BOOL range);

	int getPreset(uchar forChannel, BOOL& set, BOOL& clear);
	int setPreset(uchar forChannel, BOOL set, BOOL clear);

	int ReadVoltage();
	int DumpPage(short page, char * pageStr);
	
private:
	//data members
	uchar channels;  //00-0F in DCBA order (INPUT SELECT MASK);
	uchar preset;     //00-AA (READ-OUT CONTROL)
	uchar page0[9];	  //pages to read ds2450 memory pages
	uchar page1[9];
	uchar page2[9];
	float voltage[4];         //converted read out ABCD=0123

	//methods
	int makeConnection();		//for TMEX connection; should be part of parent class
	int readPortFromRegistry();
	int displayHeader();
	short FindFirstFamily(short family);

	int readPage(short pageno);	//Local to the 2450; possibly some virtual functions in a parent
	int writePage(short pageno);  
	float readingToVoltage(uchar forChannel);
	int forceSingleChannel(uchar forChannel);
	uchar getAddr(uchar forChannel);

	
};

//DS2450 Specific Error Messages
#define ATD_PORT_NUM_NOT_FOUND         -5
#define ATD_PORT_TYPE_NOT_FOUND        -6
#define ATD_NO_HARDWARE_DRIVER         -7
#define ATD_MICROLAN_SETUP_FAIL        -8
#define ATD_NO_DS2450_ON_MICROLAN      -9
#define ATD_NO_TYPE_VERSION_INFO_FOUND -10
#define ATD_NO_MICROLAN_SESSION        -11
#define ATD_UNAVAILABLE_PAGE          -12
#define ATD_ERROR_READING_PAGE        -13
#define ATD_UNABLE_TO_WRITE_PAGE      -14
#define ATD_FAILED_CRC_CHECK          -15
#define ATD_MULTIPLE_CHANNELS         -16
#define ATD_INCORRECT_CHANNEL         -17
#define ATD_RESOLUTION_OUT_OF_BOUNDS  -18
#define ATD_ILLEGAL_PRESET            -19

//DS2450 defined uchars for addressing channels
#define ATD_CH_A 0x01;
#define ATD_CH_B 0x02;
#define ATD_CH_C 0x04;
#define ATD_CH_D 0x08;

#endif // !defined(AFX_ATOD_H__4771592B_B4FA_11D2_A69C_00105AE399E3__INCLUDED_)
